MCPcopy Create free account
hub / github.com/ComputationalRobotics/XM-code / MarkRowKernel

Function MarkRowKernel

XM/include/Sparse/sparsesubmatrix.h:10–17  ·  view source on GitHub ↗

Your code here initialize kernal

Source from the content-addressed store, hash-verified

8// Your code here
9// initialize kernal
10__global__ void MarkRowKernel(int* row, int* col, size_s start, size_s end, size_l nnz, int* flag){
11 size_l i = blockIdx.x * blockDim.x + threadIdx.x;
12 if(i < nnz){
13 if(row[i] >= start && row[i] <= end){
14 flag[i] = 1;
15 }
16 }
17}
18
19// initialize kernal
20__global__ void MarkColKernel(int* row, int* col, size_s start, size_s end, size_l nnz, int* flag){

Callers

nothing calls this directly

Calls

no outgoing calls

Tested by

no test coverage detected